@@ -27,6 +27,7 @@ class OC(SSH):
         self.__kubeadmin_password = kubeadmin_password
         self.__environment_variables_dict = environment_variables.environment_variables_dict
         self.__run_artifacts = self.__environment_variables_dict.get('run_artifacts_path', '')
+        self.__elasticsearch_url = self.__environment_variables_dict.get('elasticsearch_url', '')
 
     def get_ocp_server_version(self):
         """
@@ -296,16 +297,17 @@ class OC(SSH):
         This method save pod log in log_path
         :param pod_name: pod name with uuid
         :param database: database
-        :return:
+        :return: output_filename
         """
         output_filename = os.path.join(self.__run_artifacts, pod_name)
         if database:
             self.run(f"oc logs -n '{database}-db' {pod_name} > {output_filename} ")
         # manager logs of benchmark-controller-manager
         elif 'benchmark-controller-manager' in pod_name:
-            self.run(f"oc logs -n {environment_variables.environment_variables_dict['namespace']} {pod_name} manager > {output_filename}; ")
+            self.run(f"oc logs -n {environment_variables.environment_variables_dict['namespace']} {pod_name} manager > {output_filename} ")
         else:
-            self.run(f"oc logs -n {environment_variables.environment_variables_dict['namespace']} {pod_name} > {output_filename}; ")
+            self.run(f"oc logs -n {environment_variables.environment_variables_dict['namespace']} {pod_name} > {output_filename} ")
+        return output_filename
 
     @typechecked
     @logger_time_stamp
@@ -317,9 +319,27 @@ class OC(SSH):
         """
         output_filename = f"{self.__run_artifacts}/{vm_name}"
         self.run(
-            cmd=f"virtctl console -n {environment_variables.environment_variables_dict['namespace']} {vm_name} | tee -a {output_filename} > {output_filename}; ",
+            cmd=f"virtctl console -n {environment_variables.environment_variables_dict['namespace']} {vm_name} > {output_filename} ",
             background=True)
 
+    @logger_time_stamp
+    def __verify_vm_log_finish(self, vm_name: str, timeout: int = int(environment_variables.environment_variables_dict['timeout'])):
+        """
+        This method verify that vm log is finish writing
+        :param vm_name: vm name with uuid
+        :return:
+        """
+        output_filename = f"{self.__run_artifacts}/{vm_name}"
+        current_wait_time = 0
+        while current_wait_time <= timeout:
+            with open(output_filename) as file:
+                if '-----END SSH HOST KEY KEYS-----' in file.read():
+                    return True
+            # sleep for x seconds
+            time.sleep(OC.SLEEP_TIME)
+            current_wait_time += OC.SLEEP_TIME
+        raise VMNotCompletedTimeout(vm_name)
+
     @logger_time_stamp
     def get_pods(self):
         """
@@ -479,6 +499,17 @@ class OC(SSH):
         else:
             return False
 
+    @typechecked
+    def delete_all_resources(self, resources: list = ('pods', 'pvc'), namespace: str = environment_variables.environment_variables_dict['namespace']):
+        """
+        This method delete all pods in namespace
+        :param resources: default list = ('pods', 'pvc')
+        :param namespace:
+        :return:
+        """
+        for resource in resources:
+            return self.run(f'oc delete -n {namespace} {resource} --all ')
+
     @typechecked
     @logger_time_stamp
     def wait_for_initialized(self, label: str, workload: str = '', status: str = 'Initialized', label_uuid: bool = True,
@@ -489,7 +520,7 @@ class OC(SSH):
         :param namespace:
         :param label:
         :param status:
-        :param label_uuid: The label include uuid
+        :param label_uuid: need to get uuid from label (benchmark-operator)
         :param timeout:
         :param workload:
         :return:
@@ -522,7 +553,7 @@ class OC(SSH):
         :param namespace:
         :param label:
         :param status:
-        :param label_uuid:  The label include uuid
+        :param label_uuid: need to get uuid from label (benchmark-operator)
         :param timeout:
         :return:
         """
@@ -545,11 +576,13 @@ class OC(SSH):
 
     @typechecked
     @logger_time_stamp
-    def wait_for_pod_completed(self, label: str, workload: str = '', namespace: str = environment_variables.environment_variables_dict['namespace'], timeout: int = int(environment_variables.environment_variables_dict['timeout'])):
+    def wait_for_pod_completed(self, label: str, workload: str = '', label_uuid: bool = True, job: bool = True, namespace: str = environment_variables.environment_variables_dict['namespace'], timeout: int = int(environment_variables.environment_variables_dict['timeout'])):
         """
         This method wait to pod to be completed
         :param workload:
         :param label:
+        :param label_uuid: need to get uuid from label (benchmark-operator)
+        :param job: kind is job instead of pod
         :param timeout:
         :param namespace:
         :return:
@@ -557,14 +590,19 @@ class OC(SSH):
         try:
             current_wait_time = 0
             while current_wait_time <= timeout:
-                result = self.run(
-                    f"oc --namespace {namespace} wait --for=condition=complete -l {label}-{self.__get_short_uuid(workload=workload)} jobs --timeout={OC.SHORT_WAIT_TIME}s")
-                if 'met' in result:
-                    return True
-                result = self.run(
-                    f"oc --namespace {namespace} wait --for=condition=failed -l {label}-{self.__get_short_uuid(workload=workload)} jobs --timeout={OC.SLEEP_TIME}s")
-                if 'met' in result:
-                    return False
+                if label_uuid and job:
+                    result = self.run(
+                        f"oc --namespace {namespace} wait --for=condition=complete -l {label}-{self.__get_short_uuid(workload=workload)} jobs --timeout={OC.SHORT_WAIT_TIME}s")
+                    if 'met' in result:
+                        return True
+                    result = self.run(
+                        f"oc --namespace {namespace} wait --for=condition=failed -l {label}-{self.__get_short_uuid(workload=workload)} jobs --timeout={OC.SLEEP_TIME}s")
+                    if 'met' in result:
+                        return False
+                if not job:
+                    result = self.run(f"oc get pod -l {label}" + " -n benchmark-runner --no-headers | awk '{ print $3; }'")
+                    if 'Completed' in result:
+                        return True
             # sleep for x seconds
             time.sleep(OC.SLEEP_TIME)
             current_wait_time += OC.SLEEP_TIME
@@ -572,11 +610,12 @@ class OC(SSH):
             raise PodNotCompletedTimeout(workload=workload)
 
     @logger_time_stamp
-    def wait_for_vm_completed(self, workload: str = '',
+    def wait_for_vm_completed(self, workload: str = '', vm_name: str = '',
                               namespace: str = environment_variables.environment_variables_dict['namespace'],
                               timeout: int = int(environment_variables.environment_variables_dict['timeout'])):
         """
         This method wait to pod to be completed
+        :param vm_name: The vm name
         :param workload:
         :param namespace:
         :return:
