@@ -115,3 +115,17 @@ class KataInstallationFailed(OCError):
     def __init__(self, reason):
         self.message = f'Installation of sandboxed containers failed: {reason}'
         super(KataInstallationFailed, self).__init__(self.message)
+
+
+class ExecFailed(OCError):
+    """exec command on pod failed"""
+    def __init__(self, pod, command, reason):
+        self.message = f'exec {command} on {pod} failed: {reason}'
+        super(ExecFailed, self).__init__(self.message)
+
+
+class PodFailed(OCError):
+    """exec command on pod failed"""
+    def __init__(self, pod):
+        self.message = f'pod {pod} failed'
+        super(PodFailed, self).__init__(self.message)
